Module api

Module api 

Structs

AsyncResponse
Response returned by requests that are asynchronous.
DeveloperGatewayApi
Holds the necessary information to make api calls.
ExecuteGatewayRequest
PollEventResponse
Response returned by a poll request containing a list of events.

Enums

Event
Structure of events that can be returned from the server.
GatewayRequest
RequestMethod

Constants

SERVICE_DEPLOY_API
This api call allows deploying a new service.
SERVICE_EXECUTE_API
This is the main api call which allows the execution of a secure service function.
SERVICE_POLL_API
This api allows users to poll for the status of submitted asynchronous requests.