pub enum Event {
Error {
id: u64,
error_code: i32,
description: String,
},
ExecuteService {
id: u64,
address: String,
output: String,
},
DeployService {
id: u64,
address: String,
},
}Expand description
Structure of events that can be returned from the server.
Variants
Error
The event as a result of a request that has failed.
Fields
ExecuteService
The event as a result of an asynchronous service request that has succeeded.
Fields
DeployService
The event as a result of an asynchronous service request that has succeeded.