GatewayRequest

Enum GatewayRequest 

pub enum GatewayRequest {
    Deploy {
        data: String,
    },
    Execute {
        address: String,
        data: String,
    },
    Poll {
        offset: u64,
        count: u32,
        discard_previous: bool,
    },
}

Variants



Deploy

Used to trigger a service deployment with provided initcode.

Fields

data: String

Hex-encoded initcode.



Execute

Used to trigger a service execution with user provided arguments.

Fields

address: String

Hex-encoded address where the service can be found.

data: String

Hex-encoded data that the user wants to pass to the service.



Poll

Request that allows the user to poll for the status asynchronous responses

Fields

offset: u64

Offset at which events need to be provided. Events are all ordered with sequence numbers and it is up to the user to specify which events it wants to receive from an offset in the sequence.

count: u32

The maximum number of items the user would prefer to receive in a single response.

discard_previous: bool

If this option is set, the server will discard the events that have a sequence number lower than the Offset.