AsyncResponse

Struct AsyncResponse 

pub struct AsyncResponse {
    pub id: u64,
}
Response returned by requests that are asynchronous.

Fields

id: u64

The response identifier. It uniquely identifies the event and orders it in the sequence of events expected by the user. The identifier can be used by the user to receive a response to the request once it is ready.