pub struct PollEventResponse {
pub offset: u64,
pub events: Vec<Event>,
}Expand description
Response returned by a poll request containing a list of events.
Fields
offset: u64The offset at which the list of events start.
events: Vec<Event>The list of events starting from the provided offset.