Structs
- Async
Response - Response returned by requests that are asynchronous.
- Developer
Gateway Api - Holds the necessary information to make api calls.
- Execute
Gateway Request - Poll
Event Response - Response returned by a poll request containing a list of events.
Enums
- Event
- Structure of events that can be returned from the server.
- Gateway
Request - Request
Method
Constants
- SERVICE_
DEPLOY_ API - This api call allows deploying a new service.
- SERVICE_
EXECUTE_ API - This is the main api call which allows the execution of a secure service function.
- SERVICE_
POLL_ API - This api allows users to poll for the status of submitted asynchronous requests.