pub enum GatewayRequest {
Deploy {
data: String,
},
Execute {
address: String,
data: String,
},
Poll {
offset: u64,
count: u32,
discard_previous: bool,
},
}Variants
Deploy
Used to trigger a service deployment with provided initcode.
Execute
Used to trigger a service execution with user provided arguments.
Fields
Poll
Request that allows the user to poll for the status asynchronous responses